/* This file is auto generated, version 1 */
/* SMP */
#define UTS_MACHINE "x86_64"
#define UTS_VERSION "#1 SMP Sat, 01 Aug 2026 08:57:06 +0000"
#define LINUX_COMPILE_BY "linux-lts515"
#define LINUX_COMPILE_HOST "archlinux"
#define LINUX_COMPILER "gcc (GCC) 16.1.1 20260728, GNU ld (GNU Binutils) 2.47"
